{# code: language=jinja-html #}
{% extends "bootstrap-gallery.html" %}

{% block gallery_head %}
  <script src="{{gallery_root_url}}/static/jquery.min.js"></script>
  <script src="{{gallery_root_url}}/static/jquery.nanogallery2.min.js"></script>
  <link rel="stylesheet" href="{{gallery_root_url}}/static/nanogallery2.min.css">
  <script>
{% include 'page.js' %}
  </script>
{% endblock %}

{% block gallery_body %}
  <!-- The gallery itself -->
  <div id="nanogallery2"></div>
{% endblock %}
