.breadcrumb-nav {
  display: inline-block;
}

.navigation-element > :first-child {
  padding-left: 2px;
}

.gallery-directories {
  margin-bottom: 15px;
}

.gallery-breadcrumb-path {
  color: var(--bs-gray);
  margin-right: 10px;
}

/* Let all numbers appear with the same width (less than 100), so the
   width justn't change from page to page */
li.page-item {
  min-width: 45px;
  text-align: center;
}